import socket
import time
import unicornhathd
import requests

try:
    from PIL import Image, ImageDraw, ImageFont
except ImportError:
    exit('This script requires the pillow module\nInstall with: sudo pip install pillow')

BITCOIN_API_URL = 'https://blockchain.info/ticker'
BITCOIN_STASH = 0.5

def get_latest_bitcoin_price():
    response = requests.get(BITCOIN_API_URL)
    response_json = response.json()
    # Convert the price to a floating point number
    response_string = "{0:.2f}".format(float(response_json[u'EUR'][u'last'])*BITCOIN_STASH)
    return "BTC: "+str(response_json[u'EUR'][u'last'])+" EUR" + "......... BTC STASH: "+response_string+" EUR"

def create_image_from_text(in_text):
    colours = (255, 255, 250)
    font_file = '/usr/share/fonts/truetype/freefont/FreeSansBold.ttf'
    font_size = 10
    font = ImageFont.truetype(font_file, font_size)
    w, h = font.getsize(in_text)

    text_x, text_y = width, 0
    text_width, text_height = width, 0

    text_width += w + width                # add some padding so the ticker scrolls off the unicorn hat
    text_height = max(text_height, h, 16)  # no more than the size of the unicorn hat

    image = Image.new('RGB', (text_width, text_height), (0, 0, 0))
    draw = ImageDraw.Draw(image)
    draw.text((text_x, text_y), in_text, colours, font=font)
    return (image, text_width)


# DISPLAY
def scroll_txt(image, text_width):
    unicornhathd.rotation(90)
    for scroll in range(text_width - width):
        for x in range(width):
            for y in range(height):
                pixel = image.getpixel((x + scroll, y))
                r, g, b = [int(n) for n in pixel]
                unicornhathd.set_pixel(width - 1 - x, y, r, g, b)
        unicornhathd.show()
        time.sleep(0.04)
    unicornhathd.off()


# one stop call for scrolling text
def scroll_text(in_txt):
    image, text_width = create_image_from_text(in_txt)
    scroll_txt(image, text_width)


if __name__ == '__main__':
    width, height = unicornhathd.get_shape()  # 16, 16 by default
    ticker = get_latest_bitcoin_price()
    scroll_text(ticker)
    scroll_text(ticker)
    scroll_text(ticker)
    scroll_text(ticker)
    scroll_text(ticker)
